@@ -91,7 +91,7 @@ class ArgumentsProcessor(object):
     """
 
     __author__ = 'James Johnson'
-    __version__ = '1.0.9'
+    __version__ = '1.1.1'
 
     supplied_arguments = {}
     expected_arguments = {}
@@ -128,22 +128,18 @@ class ArgumentsProcessor(object):
     def validate_supplied_arguments(self):
         for (expected_argument_key, expected_argument_value) in self.expected_arguments.items():
             for (supplied_argument_key, supplied_argument_value) in self.supplied_arguments.items():
-                if expected_argument_key == supplied_argument_key:
+                if supplied_argument_key == expected_argument_key:
                     if self.validate_by_rules(expected_argument_value, supplied_argument_value):
                         return True
-                    else:
-                        return False
-                else:
                     return False
+                return False
 
     def validate_by_rules(self, expected_argument_value, supplied_argument_value):
         if expected_argument_value['required'] == True:
             if self.check_supplied_argument_value_is_not_none_or_empty(supplied_argument_value):
                 return True
-            else:
-                return False
-        else:
             return False
+        return False
 
     def check_supplied_argument_value_is_not_none_or_empty(self, supplied_argument_value):
         if supplied_argument_value is None:
